@@ -8,9 +8,9 @@
 #' Models can easily be accessed via \code{\link{getLearnerModel}}.
 #'
 #' OverBagging is implemented as follows:
-#' For each iteration a random data subset is sampled. Minority class examples
+#' For each iteration a random data subset is sampled. Class examples
 #' are oversampled with replacement with a given rate.
-#' Majority class examples are either simply copied into each bag, or bootstrapped with replacement
+#' Members of the other class are either simply copied into each bag, or bootstrapped with replacement
 #' until we have as many majority class examples as in the original training data.
 #' Features are currently not changed or sampled.
 #'
@@ -23,21 +23,23 @@
 #'   Number of fitted models in bagging.
 #'   Default is 10.
 #' @param obw.rate [\code{numeric(1)}]\cr
-#'   Factor to upsample the smaller class in each bag.
+#'   Factor to upsample a class in each bag.
 #'   Must be between 1 and \code{Inf},
 #'   where 1 means no oversampling and 2 would mean doubling the class size.
 #'   Default is 1.
 #' @param obw.maxcl [\code{character(1)}]\cr
-#'   character value that controls how to sample majority class.
-#'   \dQuote{all} means every instance of the majority class gets in each bag,
-#'   \dQuote{boot} means the majority class instances are bootstrapped in each iteration.
+#'   How should other class (usually larger class) be handled?
+#'   \dQuote{all} means every instance of the class gets in each bag,
+#'   \dQuote{boot} means the class instances are bootstrapped in each iteration.
 #'   Default is \dQuote{boot}.
+#' @param obw.cl [\code{character(1)}]\cr
+#'   Which class should be over- or undersampled. If \code{NULL}, \code{makeOverBaggingWrapper}
+#'   will take the smaller class.
 #' @template ret_learner
 #' @family imbalancy
 #' @family wrapper
 #' @export
-makeOverBaggingWrapper = function(learner, obw.iters = 10L, obw.rate = 1, obw.maxcl = "boot") {
-
+makeOverBaggingWrapper = function(learner, obw.iters = 10L, obw.rate = 1, obw.maxcl = "boot", obw.cl = NULL) {
   learner = checkLearner(learner, "classif")
   pv = list()
   if (!missing(obw.iters)) {
@@ -52,6 +54,10 @@ makeOverBaggingWrapper = function(learner, obw.iters = 10L, obw.rate = 1, obw.ma
     assertChoice(obw.maxcl, choices = c("boot", "all"))
     pv$obw.maxcl = obw.maxcl
   }
+  if (!is.null(obw.cl)) {
+    assertString(obw.cl)
+    pv$obw.cl = obw.cl
+  }
 
   if (learner$predict.type != "response")
     stop("Predict type of the basic learner must be response.")
@@ -60,7 +66,8 @@ makeOverBaggingWrapper = function(learner, obw.iters = 10L, obw.rate = 1, obw.ma
   ps = makeParamSet(
     makeIntegerLearnerParam(id = "obw.iters", lower = 1L, default = 10L),
     makeNumericLearnerParam(id = "obw.rate", lower = 1),
-    makeDiscreteLearnerParam(id = "obw.maxcl", c("boot", "all"))
+    makeDiscreteLearnerParam(id = "obw.maxcl", c("boot", "all")),
+    makeUntypedLearnerParam(id = "obw.cl", default = NULL)
   )
   makeHomogeneousEnsemble(id, "classif", learner, packs, par.set = ps, par.vals = pv,
      learner.subclass = c("OverBaggingWrapper", "BaggingWrapper"), model.subclass = "BaggingModel")
@@ -68,13 +75,16 @@ makeOverBaggingWrapper = function(learner, obw.iters = 10L, obw.rate = 1, obw.ma
 
 #' @export
 trainLearner.OverBaggingWrapper = function(.learner, .task, .subset, .weights = NULL,
-   obw.iters = 10L, obw.rate = 1, obw.maxcl = "boot", ...) {
+   obw.iters = 10L, obw.rate = 1, obw.maxcl = "boot", obw.cl = NULL, ...) {
 
   .task = subsetTask(.task, subset = .subset)
   y = getTaskTargets(.task)
+  if (is.null(obw.cl)) {
+    z = getMinMaxClass(y)
+    obw.cl = z$min.name
+  }
   models = lapply(seq_len(obw.iters), function(i) {
-    bag = sampleBinaryClass(y, obw.rate, cl = "min", clreplace = TRUE,
-      othreplace = (obw.maxcl == "boot"), bagging = TRUE)
+    bag = sampleBinaryClass(y, rate = obw.rate, cl = obw.cl, resample.other.class = (obw.maxcl == "boot"))
     train(.learner$next.learner, .task, subset = bag, weights = .weights)
   })
   m = makeHomChainModel(.learner, models)
