@@ -11,7 +11,7 @@ makeRLearner.classif.binomial = function() {
     properties = c("twoclass", "numerics", "factors", "prob", "weights"),
     name = "Binomial Regression",
     short.name = "binomial",
-    note = "Delegates to glm with freely choosable binomial link function via learner param 'link'."
+    note = "Delegates to `glm` with freely choosable binomial link function via learner parameter `link`."
   )
 }
 
