@@ -29,7 +29,7 @@ makeRLearner.classif.cforest = function() {
     par.vals = list(),
     name = "Random forest based on conditional inference trees",
     short.name = "cforest",
-    note = "see ?ctree_control for possible breakage for nominal features with missingness"
+    note = "See `?ctree_control` for possible breakage for nominal features with missingness."
   )
 }
 
@@ -40,7 +40,13 @@ trainLearner.classif.cforest = function(.learner, .task, .subset,
   nresample, maxsurrogate, maxdepth, savesplitstats, ...) {
   f = getTaskFormula(.task)
   d = getTaskData(.task, .subset)
-  ctrl = learnerArgsToControl(party::cforest_unbiased, ntree, mtry, replace,
+  defaults = getDefaults(getParamSet(.learner))
+  if (missing(teststat)) teststat = defaults$teststat
+  if (missing(testtype)) testtype = defaults$testtype
+  if (missing(mincriterion)) mincriterion = defaults$mincriterion
+  if (missing(replace)) replace = defaults$replace
+  if (missing(fraction)) fraction = defaults$fraction
+  ctrl = learnerArgsToControl(party::cforest_control, ntree, mtry, replace,
     fraction, trace, pvalue, teststat, testtype, mincriterion, minprob,
     minsplit, minbucket, stump, randomsplits, nresample, maxsurrogate,
     maxdepth, savesplitstats)
