@@ -4,8 +4,9 @@ makeRLearner.classif.geoDA = function() {
     cl = "classif.geoDA",
     package = "DiscriMiner",
     par.set = makeParamSet(
-      makeDiscreteLearnerParam(id = "validation", values = c("crossval", "learntest"))
+      makeDiscreteLearnerParam(id = "validation", values = list(crossval = "crossval", learntest = "learntest", NULL = NULL), default = NULL, tunable = FALSE)
     ),
+    par.vals = list(validation = NULL),
     properties = c("twoclass", "multiclass", "numerics"),
     name = "Geometric Predictive Discriminant Analysis",
     short.name = "geoda",
