@@ -14,7 +14,7 @@ makeRLearner.classif.lda = function() {
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
     name = "Linear Discriminant Analysis",
     short.name = "lda",
-    note = "Learner param 'predict.method' maps to 'method' in predict.lda."
+    note = "Learner parameter `predict.method` maps to `method` in `predict.lda`."
   )
 }
 
