@@ -5,12 +5,12 @@ makeRLearner.classif.linDA = function() {
     package = "DiscriMiner",
     par.set = makeParamSet(
       #makeNumericVectorLearnerParam(id = "prior", lower = 0, upper = 1, default = NULL),
-      makeDiscreteLearnerParam(id = "validation", values = c("crossval", "learntest"))
-      ),
+      makeDiscreteLearnerParam(id = "validation", values = list(crossval = "crossval", learntest = "learntest", NULL = NULL), default = NULL, tunable = FALSE)
+    ),
     properties = c("twoclass", "multiclass", "numerics"),
     name = "Linear Discriminant Analysis",
     short.name = "linda",
-    note = ""
+    note = "Set `validation = NULL` by default to disable internal test set validation."
   )
 }
 
