@@ -12,7 +12,7 @@ makeRLearner.classif.qda = function() {
     properties = c("twoclass", "multiclass", "numerics", "factors", "prob"),
     name = "Quadratic Discriminant Analysis",
     short.name = "qda",
-    note = "Learner param 'predict.method' maps to 'method' in predict.lda."
+    note = "Learner parameter `predict.method` maps to `method` in `predict.qda`."
   )
 }
 
