@@ -5,8 +5,8 @@ makeRLearner.classif.quaDA = function() {
     package = "DiscriMiner",
     par.set = makeParamSet(
       #makeNumericVectorLearnerParam(id = "prior", lower = 0, upper = 1, default = NULL),
-      makeDiscreteLearnerParam(id = "validation", values = c("crossval", "learntest"))
-      ),
+      makeDiscreteLearnerParam(id = "validation", values = list(crossval = "crossval", learntest = "learntest", NULL = NULL), default = NULL, tunable = FALSE)
+    ),
     properties = c("twoclass", "multiclass", "numerics"),
     name = "Quadratic Discriminant Analysis",
     short.name = "quada",
