@@ -24,7 +24,7 @@ makeRLearner.classif.xyf = function() {
 
 #' @export
 trainLearner.classif.xyf = function(.learner, .task, .subset, .weights = NULL, xdim, ydim, topo, ...) {
-  d = getTaskData(.task, .subset, target.extra = T)
+  d = getTaskData(.task, .subset, target.extra = TRUE)
   grid = learnerArgsToControl(class::somgrid, xdim, ydim, topo)
   kohonen::xyf(as.matrix(d$data), Y = d$target, grid = grid, keep.data = FALSE, ...)
 }
