@@ -14,7 +14,7 @@ makeRLearner.cluster.kmeans = function() {
     par.vals = list(centers = 2L),
     properties = c("numerics", "prob"),
     name = "K-Means",
-    note = "The 'predict' method uses 'cl_predict' from the 'clue' package to compute the cluster memberships for new data. The default 'centers=2' is added so the method runs without setting params, but this must in reality of course be changed by the user.",
+    note = "The `predict` method uses `cl_predict` from the `clue` package to compute the cluster memberships for new data. The default `centers = 2` is added so the method runs without setting parameters, but this must in reality of course be changed by the user.",
     short.name = "kmeans"
   )
 }
