@@ -33,7 +33,7 @@ makeRLearner.regr.ksvm = function() {
     properties = c("numerics", "factors"),
     name = "Support Vector Machines",
     short.name = "ksvm",
-    note = "Kernel parameters have to be passed directly and not by using the kpar list in ksvm. Note that `fit` has been set to `FALSE` by default for speed."
+    note = "Kernel parameters have to be passed directly and not by using the `kpar` list in `ksvm`. Note that `fit` has been set to `FALSE` by default for speed."
   )
 }
 
