@@ -10,7 +10,7 @@ makeRLearner.regr.rsm = function() {
     properties = c("numerics"),
     name = "Response Surface Regression",
     short.name = "rsm",
-    note = "You select the order of the regression by using modelfun = \"FO\" (first order), \"TWI\" (two-way interactions, this is with 1st oder terms!) and \"SO\" (full second order)"
+    note = 'You select the order of the regression by using `modelfun = "FO"` (first order), `"TWI"` (two-way interactions, this is with 1st oder terms!) and `"SO"` (full second order).'
   )
 }
 
@@ -25,7 +25,7 @@ trainLearner.regr.rsm = function(.learner, .task, .subset, .weights = NULL,  ...
     SO = g("SO"),
     stop("Unknown modelfun: ", mf)
   )
-  f = as.formula(paste(.task$task.desc$target, "~", mf))
+  f = as.formula(paste(getTaskTargetNames(.task), "~", mf))
   myargs = list(f, getTaskData(.task, .subset))
   # strange behaviour in rsm forces us to use do.call...
   do.call(rsm::rsm, myargs)
