@@ -26,15 +26,13 @@ makeRLearner.regr.rvm = function() {
       makeNumericLearnerParam(id = "minmaxdiff", default = 0.001, lower = 0),
       makeLogicalLearnerParam(id = "verbosity", default = FALSE, tunable = FALSE),
       makeLogicalLearnerParam(id = "fit", default = TRUE),
-      makeIntegerLearnerParam(id = "cross", default = 0L, lower = 0L)
+      makeIntegerLearnerParam(id = "cross", default = 0L, lower = 0L, tunable = FALSE)
     ),
     par.vals = list(fit = FALSE),
     properties = c("numerics", "factors"),
     name = "Relevance Vector Machine",
     short.name = "rvm",
-    note = "Kernel parameters have to be passed directly and not by using the kpar list in rvm.
-
- Note that `fit` has been set to `FALSE` by default for speed."
+    note = "Kernel parameters have to be passed directly and not by using the `kpar` list in `rvm`. Note that `fit` has been set to `FALSE` by default for speed."
   )
 }
 
