@@ -21,7 +21,7 @@ makeRLearner.surv.glmboost = function() {
     short.name = "glmboost",
     note = paste(
       "`family` has been set to `CoxPH()` by default.",
-      "Maximum number of boosting iterations is set via 'mstop', the actual number used for prediction is controlled by 'm'."
+      "Maximum number of boosting iterations is set via `mstop`, the actual number used for prediction is controlled by `m`."
     )
   )
 }
