@@ -4,22 +4,31 @@ makeRLearner.surv.optimCoxBoostPenalty = function() {
     cl = "surv.optimCoxBoostPenalty",
     package = "!CoxBoost",
     par.set = makeParamSet(
-      makeIntegerLearnerParam(id = "maxstepno", default = 100, lower = 0),
-      makeIntegerLearnerParam(id = "K", default = 10, lower = 1),
-      makeDiscreteLearnerParam(id = "type", default = "verweij", values = c("verweij", "naive")),
+      makeIntegerLearnerParam(id = "minstepno", default = 50L, lower = 0L),
+      makeIntegerLearnerParam(id = "maxstepno", default = 100L, lower = 0L),
+      makeIntegerLearnerParam(id = "K", default = 10L, lower = 1L),
+      makeDiscreteLearnerParam(id = "type", default = "verweij",
+        values = c("verweij", "naive")),
       makeLogicalLearnerParam(id = "standardize", default = TRUE),
-      makeDiscreteLearnerParam(id = "criterion", default = "pscore", values = c("pscore", "score", "hpscore", "hscore")),
+      makeDiscreteLearnerParam(id = "criterion", default = "pscore",
+        values = c("pscore", "score", "hpscore", "hscore")),
       makeNumericLearnerParam(id = "stepsize.factor", default = 1, lower = 0),
-      makeDiscreteLearnerParam(id = "sf.scheme", default = "sigmoid", values = c("sigmoid", "linear")),
-      makeIntegerLearnerParam(id = "iter.max", default = 10, lower = 1),
-      makeLogicalLearnerParam(id = "return.score", default = TRUE)
+      makeDiscreteLearnerParam(id = "sf.scheme", default = "sigmoid",
+        values = c("sigmoid", "linear")),
+      makeIntegerLearnerParam(id = "iter.max", default = 10L, lower = 1L),
+      makeNumericLearnerParam(id = "upper.margin", default = 0.05, lower = 0, upper = 1),
+      makeLogicalLearnerParam(id = "return.score", default = TRUE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "parallel", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "upload.x", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "multicore", default = FALSE, tunable = FALSE),
+      makeLogicalLearnerParam(id = "trace", default = FALSE, tunable = FALSE)
       # FIXME: still missing some arguments
     ),
     par.vals = list(return.score = FALSE),
     properties = c("numerics", "factors", "weights", "rcens"),
     name = "Cox Proportional Hazards Model with Componentwise Likelihood based Boosting, automatic tuning enabled",
     short.name = "optimCoxBoostPenalty",
-    note = "Factors automatically get converted to dummy columns, ordered factors to integer"
+    note = "Factors automatically get converted to dummy columns, ordered factors to integer."
   )
 }
 
