@@ -3,9 +3,10 @@
 #' Mainly for internal use. Predict new data with a fitted model.
 #' You have to implement this method if you want to add another learner to this package.
 #'
-#' You implementation must adhere to the following:
-#' The model must be fitted on the subset of \code{.task} given by \code{.subset}. All parameters
-#' in \code{...} must be passed to the underlying training function.
+#' Your implementation must adhere to the following:
+#' Predictions for the observations in \code{.newdata} must be made based on the fitted
+#' model (\code{.model$learner.model}).
+#' All parameters in \code{...} must be passed to the underlying predict function.
 #'
 #' @param .learner [\code{\link{RLearner}}]\cr
 #'   Wrapped learner.
@@ -15,11 +16,25 @@
 #'   New data to predict. Does not include target column.
 #' @param ... [any]\cr
 #'   Additional parameters, which need to be passed to the underlying predict function.
-#' @return For classification: Either a factor for type \dQuote{response} or a matrix for
-#'   type \dQuote{prob}. In the latter case the columns must be named with the class labels.
-#'   For regressions: Either a numeric for type \dQuote{response} or a matrix with two columns
-#'   for type \dQuote{se}. In the latter case first column is the estimated response (mean value)
-#'   and the second column the estimated standard errors.
+#' @return
+#' \itemize{
+#'   \item For classification: Either a factor with class labels for type
+#'     \dQuote{response} or, if the learner supports this, a matrix of class probabilities
+#'     for type \dQuote{prob}. In the latter case the columns must be named with the class
+#'     labels.
+#'   \item For regression: Either a numeric vector for type \dQuote{response} or,
+#'     if the learner supports this, a matrix with two columns for type \dQuote{se}.
+#'     In the latter case the first column contains the estimated response (mean value)
+#'     and the second column the estimated standard errors.
+#'   \item For survival: Either a numeric vector with some sort of orderable risk
+#'     for type \dQuote{response} or, if supported, a numeric vector with time dependent
+#'     probabilities for type \dQuote{prob}.
+#'   \item For clustering: Either an integer with cluster IDs for type \dQuote{response}
+#'     or, if supported, a matrix of membership probabilities for type \dQuote{prob}.
+#'   \item For multilabel: A logical matrix that indicates predicted class labels for type
+#'     \dQuote{response} or, if supported, a matrix of class probabilities for type
+#'     \dQuote{prob}. The columns must be named with the class labels.
+#'  }
 #' @export
 predictLearner = function(.learner, .model, .newdata, ...) {
   lmod = getLearnerModel(.model)
@@ -71,7 +86,7 @@ checkPredictLearnerOutput = function(learner, model, p) {
         stopf("predictLearner for %s has returned not the class levels as column names: %s",
           learner$id, collapse(colnames(p)))
     }
-  } else if (learner$type == "regr")  {
+  } else if (learner$type == "regr") {
     if (learner$predict.type == "response") {
       if (cl != "numeric")
         stopf("predictLearner for %s has returned a class %s instead of a numeric!", learner$id, cl)
@@ -81,6 +96,27 @@ checkPredictLearnerOutput = function(learner, model, p) {
       if (ncol(p) != 2L)
         stopf("predictLearner for %s has not returned a numeric matrix with 2 columns!", learner$id)
     }
+  } else if (learner$type == "surv") {
+    if (learner$predict.type == "prob")
+      stop("Survival does not support prediction of probabilites yet.")
+    if (!is.numeric(p))
+      stopf("predictLearner for %s has returned a class %s instead of a numeric!", learner$id, cl)
+  } else if (learner$type == "cluster")  {
+    if (learner$predict.type == "response") {
+      if (cl != "integer")
+        stopf("predictLearner for %s has returned a class %s instead of an integer!", learner$id, cl)
+    } else if (learner$predict.type == "prob") {
+      if (!is.matrix(p))
+        stopf("predictLearner for %s has returned a class %s instead of a matrix!", learner$id, cl)
+    }
+  } else if (learner$type == "multilabel")  {
+    if (learner$predict.type == "response") {
+      if (!(is.matrix(p) && typeof(p) == "logical"))
+        stopf("predictLearner for %s has returned a class %s instead of a logical matrix!", learner$id, cl)
+     } else if (learner$predict.type == "prob") {
+      if (!(is.matrix(p) && typeof(p) == "double"))
+        stopf("predictLearner for %s has returned a class %s instead of a numerical matrix!", learner$id, cl)
+    }
   }
   return(p)
 }
