@@ -7,13 +7,13 @@ test_that("costs", {
   task$task.desc$positive = "M"
 
   cc = 1 - diag(1, 2)
-  rownames(cc) = colnames(cc) = task$task.desc$class.levels
+  rownames(cc) = colnames(cc) = getTaskClassLevels(task)
   ms = makeCostMeasure(costs = cc, task = task)
   r = resample(lrn, rdesc, task = task, measures = list(mmce, ms))
   expect_equal(r$aggr[[1]], r$aggr[[2]])
 
   cc = matrix(0, 2, 2)
-  rownames(cc) = colnames(cc) = task$task.desc$class.levels
+  rownames(cc) = colnames(cc) = getTaskClassLevels(task)
   cc["R","M"] = 1
   ms = makeCostMeasure(id = "foo", costs = cc, task = task, combine = sum)
   expect_equal(ms$id, "foo")
