@@ -1,4 +1,4 @@
-context("generateCalibrationData")
+context("generateCalibration")
 
 test_that("generateCalibrationData", {
   ## single prediction
@@ -13,8 +13,8 @@ test_that("generateCalibrationData", {
   path = paste0(dir, "/test.svg")
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(unique(cd$data$Learner))))
-  expect_that(length(XML::getNodeSet(doc, red.xpath, "svg")), equals(nrow(cd$proportion) + 1))
+  expect_that(length(XML::getNodeSet(doc, lightgrey.xpath, ns.svg)), equals(length(unique(cd$data$Learner))))
+  expect_that(length(XML::getNodeSet(doc, red.xpath, ns.svg)), equals(nrow(cd$proportion) + 1))
 
   ## resample prediction
   rdesc = makeResampleDesc("CV", iters = 2L)
@@ -27,8 +27,8 @@ test_that("generateCalibrationData", {
   path = paste0(dir, "/test.svg")
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(unique(cd$data$Learner))))
-  expect_that(length(XML::getNodeSet(doc, red.xpath, "svg")), equals(nrow(cd$proportion) + 1))
+  expect_that(length(XML::getNodeSet(doc, lightgrey.xpath, ns.svg)), equals(length(unique(cd$data$Learner))))
+  expect_that(length(XML::getNodeSet(doc, red.xpath, ns.svg)), equals(nrow(cd$proportion) + 1))
 
   ## benchmark result
   lrns = list(lrn, makeLearner("classif.lda", predict.type = "prob"))
@@ -37,8 +37,8 @@ test_that("generateCalibrationData", {
   plotCalibration(cd)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(unique(cd$data$Learner))))
-  expect_that(length(XML::getNodeSet(doc, red.xpath, "svg")), equals(nrow(cd$proportion) + 1))
+  expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(unique(cd$data$Learner))))
+  expect_that(length(XML::getNodeSet(doc, red.xpath, ns.svg)), equals(nrow(cd$proportion) + 1))
 
   ## list of resample predictions
   rs = lapply(lrns, crossval, task = binaryclass.task, iters = 2L)
@@ -47,6 +47,6 @@ test_that("generateCalibrationData", {
   plotCalibration(cd)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(unique(cd$data$Learner))))
-  expect_that(length(XML::getNodeSet(doc, red.xpath, "svg")), equals(nrow(cd$proportion) + 1))
+  expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(unique(cd$data$Learner))))
+  expect_that(length(XML::getNodeSet(doc, red.xpath, ns.svg)), equals(nrow(cd$proportion) + 1))
 })
