@@ -1,4 +1,4 @@
-context("generateThreshVsPerfData")
+context("generateThreshVsPerf")
 
 test_that("generateThreshVsPerfData", {
   ## single prediction
@@ -11,14 +11,14 @@ test_that("generateThreshVsPerfData", {
   path = paste0(dir, "/test.svg")
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(pvs$measures)))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")), equals(length(pvs$measures)))
+  expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(pvs$measures)))
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(pvs$measures)))
   ## plotThreshVsPerfGGVIS(pvs)
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")), equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(1L))
 
   ## resample prediction
   rdesc = makeResampleDesc("CV", iters = 2L)
@@ -27,20 +27,27 @@ test_that("generateThreshVsPerfData", {
   plotThreshVsPerf(pvs)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(pvs$measures)))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")), equals(length(pvs$measures)))
+  expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(pvs$measures)))
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(pvs$measures)))
   ## plotThreshVsPerfGGVIS(pvs)
 
+  pvs = generateThreshVsPerfData(r, list(tpr, fpr), aggregate = FALSE)
+  plotThreshVsPerf(pvs)
+  ggsave(path)
+  doc = XML::xmlParse(path)
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)),
+              equals(length(pvs$measures) * length(unique(pvs$data$iter))))
+
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")), equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(unique(pvs$data$iter))))
 
   pvs = generateThreshVsPerfData(r, list(tpr, fpr), aggregate = FALSE)
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")), equals(rdesc$iters))
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(rdesc$iters))
 
   ## benchmark result
   lrns = list(lrn, makeLearner("classif.lda", predict.type = "prob"))
@@ -50,21 +57,21 @@ test_that("generateThreshVsPerfData", {
   plotThreshVsPerf(pvs)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(pvs$measures)))
-  expect_that(length(XML::getNodeSet(doc, red.line.xpath, "svg")) - 1, equals(length(unique(pvs$data$learner))))
-  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, "svg")) - 1, equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(pvs$measures)))
+  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)) - 1, equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)) - 1, equals(length(unique(pvs$data$learner))))
   ## plotThreshVsPerfGGVIS(pvs)
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")), equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
 
   pvs = generateThreshVsPerfData(res, list(tpr, fpr), aggregate = FALSE)
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")),
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)),
               equals(rdesc$iters * length(unique(pvs$data$learner))))
 
   ## list of resample predictions
@@ -74,23 +81,23 @@ test_that("generateThreshVsPerfData", {
   plotThreshVsPerf(pvs)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(pvs$measures)))
-  expect_that(length(XML::getNodeSet(doc, red.line.xpath, "svg")) - 1, equals(length(unique(pvs$data$learner))))
-  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, "svg")) - 1, equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(pvs$measures)))
+  expect_that(length(XML::getNodeSet(doc, red.line.xpath, ns.svg)) - 1, equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, blue.line.xpath, ns.svg)) - 1, equals(length(unique(pvs$data$learner))))
   ## plotThreshVsPerfGGVIS(pvs)
 
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(unique(pvs$data$learner))))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")), equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
 
   pvs = generateThreshVsPerfData(rs, list(tpr, fpr), aggregate = FALSE)
   plotROCCurves(pvs, list(fpr, tpr), diagonal = FALSE)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(unique(pvs$data$learner))))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")),
+  expect_that(length(XML::getNodeSet(doc, grey.xpath, ns.svg)), equals(length(unique(pvs$data$learner))))
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)),
               equals(rdesc$iters * length(unique(pvs$data$learner))))
 
   ## test prediction obj with custom measure
@@ -103,8 +110,6 @@ test_that("generateThreshVsPerfData", {
   plotThreshVsPerf(pvs.custom)
   ggsave(path)
   doc = XML::xmlParse(path)
-  expect_that(length(XML::getNodeSet(doc, grey.xpath, "svg")), equals(length(pvs.custom$measures)))
-  expect_that(length(XML::getNodeSet(doc, black.line.xpath, "svg")), equals(length(unique(pvs.custom$data$learner))))
-
+  expect_that(length(XML::getNodeSet(doc, black.line.xpath, ns.svg)), equals(1L))
   ## plotThreshVsPerfGGVIS(pvs.custom)
 })
