@@ -28,7 +28,7 @@ test_that("smote works with rate 1 (no new examples)",  {
   tab2 = table(df[, binaryclass.target])
   expect_equal(tab2["M"], tab1["M"])
   expect_equal(tab2["R"], tab1["R"])
-  
+
   taskAlt = smote(binaryclass.task, rate = 1, alt.logic = TRUE)
   dfAlt = getTaskData(taskAlt)
   tab2Alt = table(dfAlt[, binaryclass.target])
@@ -45,9 +45,9 @@ test_that("smote works with only factor features",  {
   )
   task = makeClassifTask(data = d, target = "y")
   task2 = smote(task, rate = 1.4, nn = 2L)
-  expect_equal(task2$task.desc$size, 11)
+  expect_equal(getTaskSize(task2), 11)
   task3 = smote(task, rate = 2, nn = 2L, alt.logic = TRUE)
-  expect_equal(task3$task.desc$size, 12)
+  expect_equal(getTaskSize(task3), 12)
 })
 
 test_that("smote wrapper",  {
@@ -55,11 +55,11 @@ test_that("smote wrapper",  {
   lrn1 = makeLearner("classif.rpart")
   lrn2 = makeSMOTEWrapper(lrn1, sw.rate = 2)
   r = resample(lrn2, binaryclass.task, rdesc)
-  expect_true(!is.na(r$aggr))  
+  expect_true(!is.na(r$aggr))
   lrn3 = makeSMOTEWrapper(lrn1, sw.rate = 2, sw.standardize = TRUE)
   r = resample(lrn3, binaryclass.task, rdesc)
-  expect_true(!is.na(r$aggr))  
+  expect_true(!is.na(r$aggr))
   lrn4 = makeSMOTEWrapper(lrn1, sw.rate = 2, sw.alt.logic = TRUE)
   r = resample(lrn4, binaryclass.task, rdesc)
-  expect_true(!is.na(r$aggr))  
+  expect_true(!is.na(r$aggr))
 })
