@@ -1,4 +1,4 @@
-context("resample: holdout")
+context("resample_holdout")
 
 test_that("holdout instance works", {
   rin = makeResampleInstance(makeResampleDesc("Holdout", split=0.25), size=20)
