@@ -17,4 +17,10 @@ test_that("FilterWrapper", {
   expect_subset(r$extract[[1]][[1]], getTaskFeatureNames(binaryclass.task))
 })
 
-
+test_that("FilterWrapper univariate (issue #516)", {
+  lrn1 = makeLearner("classif.rpart")
+  lrn2 = makeFilterWrapper(lrn1, fw.method = "univariate.model.score", fw.perc = 1)
+  m = train(lrn2, binaryclass.task)
+  expect_true(!inherits(m, "FailureModel"))
+  expect_equal(m$features, getTaskFeatureNames(binaryclass.task))
+})
