@@ -1,9 +1,11 @@
+context("learners_all_clusters")
+
 test_that("learners work: cluster", {
 
   # clustering, response
   task = noclass.task
   lrns = mylist(task, create = TRUE)
-  for (lrn in lrns) {
+  for (lrn in lrns$class) {
     # FIXME: remove this if DBscan runs stable
     if (!inherits(lrn, "cluster.DBScan")) {
       expect_output(print(lrn), lrn$id)
@@ -17,7 +19,7 @@ test_that("learners work: cluster", {
   task = subsetTask(noclass.task, subset = 1:20,
     features = getTaskFeatureNames(noclass.task)[1:2])
   lrns = mylist(task, properties = "prob")
-  lrns = lapply(lrns, makeLearner, predict.type = "prob")
+  lrns = lapply(lrns$class, makeLearner, predict.type = "prob")
   lapply(lrns, function(lrn) {
     m = train(lrn, task)
     p = predict(m, task)
